eprllib.ActionFunctions — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.ActionFunctions

## Action Functions

This module defines the functions that are used to perform actions on the environment. The functions are used in the EnvConfig class to specify the actions that can be performed on the environment.

Modules

`ActionFunctions` | Action Function Base Class
`setpoint_control` | Setpoint Controls
`window_opening_control` | Window Opening Contros
`window_shading_control` | Window Shading Control